@@ -1,6 +1,6 @@
 #!/bin/bash
 ## GophHub - Gopher proxy for GitHub API
-VERSION=1.0
+VERSION=1.1
 ## Designed for Gophernicus CGI environment
 ##
 ## URL parameters:
@@ -161,6 +161,8 @@ done
 # If no "repo" specified, display home menu gophermap
 if [ -z "$repo" ]
 then
+ # Decode percent-encoded characters (eg. from Web proxies)
+ SEARCHREQUEST="$(printf '%b' "${SEARCHREQUEST//%/\\x}")"
  # Extract repo "owner/name" from URL in search request
  if repo="`expr \"$SEARCHREQUEST\" : '.*github\.[[:alpha:]]*/\([^/]*/[^/#]*\)'`"
  then
@@ -347,26 +349,26 @@ then
   | while read -r start FIELD sep VALUE comma || {
         # This part runs after the end of the end of output from Grep
         echo "!GophHub - ${repo}:"
-        echo "$DESCVAL" | fold -s -w 68
+        echo "$DESCVAL"
         [ "$HOMEVAL" ] && echo -e "h Project's Website\tURL:$HOMEVAL"
         echo -e "h Download Repo ZIP Archive\tURL:https://api.github.com/repos/$repo/zipball"
         echo -e "h GitHub URL: https://github.com/$repo.git\tURL:https://github.com/$repo.git\n"\
           "Repo Size: $SIZEVAL\n"\
           "Programming Language: $LANGVAL\n"\
           "License: $LICENSEVAL"
-        [ "$DATEVAL" ] && echo -e "Latest Commit Date: $DATEVAL\n"\
-                                  "Latest Commit Message:\n$MESSAGEVAL"
+        [ "$DATEVAL" ] && echo -e -n " Latest Commit Date: $DATEVAL\n"\
+                                  "Latest Commit Message:\n$MESSAGEVAL\n"
         false
        }
   do
    case "$FIELD" in
-    description) DESCVAL="$VALUE" ;;
+    description) DESCVAL="`echo -e \"$VALUE\" | fold -s -w 67 | pr -o 1 -T`" ;;
     homepage) HOMEVAL="$VALUE" ;;
     size) sep="${sep#: *}"; SIZEVAL="`numfmt --to=iec --from=iec \"${sep%,}\"K`" ;;
     language) LANGVAL="$VALUE" ;;
     spdx_id) LICENSEVAL="$VALUE" ;;
     date) DATEVAL="$VALUE" ;;
-    message) MESSAGEVAL="`echo -e \"$VALUE\" | fold -s -w 70`" ;;
+    message) MESSAGEVAL="`echo -e \"$VALUE\" | fold -s -w 66 | pr -o 2 -T`" ;;
    esac
   done
   IFS="$oldIFS" # Take '"' off IFS
@@ -428,7 +430,7 @@ then
   echo '______________________________________________________________________'
   # Display default readme for the repo, with text wrapped and indented one space from the left.
   # Outputs one 'page' of $READMEMAX lines.
-  [ $READMEMAX -gt 0 ] && fold -w 69 -s readme | pr -o 1 -T -l $READMEMAX +1:1
+  [ $READMEMAX -gt 0 ] && fold -w 67 -s readme | pr -o 1 -T -l $READMEMAX +1:1
   echo '______________________________________________________________________'
   echo -e "hFull README in HTML\t$CGIPATH?repo=${repo}${carry}&file=readme"
   # Show latest release, if there is one
